; docformat = 'rst'
;+
; .. _amsu2ncdf.pro:
;
; =============
; amsu2ncdf.pro
; =============
;
; DESCRIPTION
; ===========
;
; +todo+
;
;    :param use_amsua: flag to tell if amsub only or amsub
;    :type use_amsua: int 0 or 1
;    :raise use_amsua: required
;
;    :param yyyy: year
;    :type yyyy: int
;    :raise yyyy: required
;
;    :param mm: month
;    :type mm: int
;    :raise mm: required
;
;    :param dd: day
;    :type dd: int
;    :raise dd: required
;
;    :param lon_min: longitude min, W < 0
;    :units lon_min: deg
;    :type lon_min: double
;    :raise lon_min: required
;
;    :param lon_max: longitude max, W < 0
;    :units lon_max: deg
;    :type lon_max: double
;    :raise lon_max: required
;
;    :param lat_min: latitude min, N > 0
;    :units lat_min: deg
;    :type lat_min: double
;    :raise lat_min: required
;
;    :param lat_max: latitude max, N > 0
;    :units lat_max: deg
;    :type lat_max: double
;    :raise lat_max: required
;
; read :file:`${PROJECT_ID}/AMSU/yyyy/mm/dd/amsua[_amsub]_{yyyymmdd}_{geomin}_{geomax}_nadir.dat`
; produced by :ref:`correct_nadir_amsu.pro`.
;
; read :file:`${PROJECT_ID}/MSG/2006/06/01/msg_IR108_20060601.nc` that will
; be used for regrid.++
;
; write :file:`${PROJECT_ID}/AMSU/yyyy/mm/dd/amsua[_amsub]_{yyyymmdd}_{hhmmss}_{geomin}_{geomax}_nadir.nc`.
;
; .. only:: man
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph amsu2ncdf {
;
;           amsu_t3 [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.dat"];
;           amsu_t4 [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.nc"];
;           msg [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MSG/2006/06/01/msg_IR108_20060601.nc"];
;
;           amsu2ncdf [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/amsu2ncdf.pro",
;           label="${PROJECT}/src/amsu2ncdf.pro"];
;
;           {amsu_t3 msg} -> {amsu2ncdf} -> {amsu_t4}
;
;          }
;
; EXAMPLES
; ========
;
; To produce AMSU netCDF file for 20060801::
;
;   use_amsua=1
;   yyyy=2006L
;   mm=8
;   dd=01
;   lon_min=-60.
;   lon_max=50.
;   lat_min=-30.
;   lat_max=45.
;   amsu2ncdf, use_amsua, yyyy, mm, dd, lon_min, lon_max, lat_min, lat_max
;
; or::
;
;   use_amsua=0
;   yyyy=2006L
;   mm=8
;   dd=01
;   lon_min=-60.
;   lon_max=50.
;   lat_min=-30.
;   lat_max=45.
;   amsu2ncdf, use_amsua, yyyy, mm, dd, lon_min, lon_max, lat_min, lat_max
;
;
; SEE ALSO
; ========
;
; :ref:`data_amsu`
; :ref:`data_msg`
;
; Use: :func:`read_regular_grid`, :ref:`create_amsu_netcdf.pro`, :func:`geolocation_to_string_idl`
;
; Called by :ref:`traite_amsuab.sh`
;
; Previous step : :ref:`extract_amsu.pro`
;
; Next step : ... science !
;
; TODO
; ====
;
;
; EVOLUTIONS
; ==========
;
;
;-
PRO amsu2ncdf, use_amsua, yyyy, mm, dd, lon_min, lon_max, lat_min, lat_max,resol
;
compile_opt idl2, strictarrsubs
;
@cm_project
testfilename=''
prefix=numch
look = 'filename'

geomin = geolocation_to_string_idl(lon_min, lat_min, look,1)
geomax = geolocation_to_string_idl(lon_max, lat_max, look,1)

result=file_amsu_t2_to_mem( yyyy,mm,dd,numch,lon_min,lon_max,lat_min,lat_max,testfilename)
         desc=result.data.desc
         hour=result.data.hour
         fov=result.data.fov
         lon=result.data.lon
         lat=result.data.lat
         mask=result.data.landseamask
         tb1=result.data.tb
         ; decodage du nb de points (nn)
         nn=n_elements(tb1)

; grille de sortie xaxis, yaxis :
; --------------------------------
;    lon : (indgen((maxlon-minlon)/resolt+1)+long(minlon/resolt))*resolt+resolt/2., $
;    lat : (indgen((maxlat-minlat)/resolt+1)+long(minlat/resolt))*resolt+resolt/2. $
xaxis=indgen((lmon_max-lon_min)/resol+1)
yaxis=indgen((lat_max-lat_min)/resol+1)
print,xaxis,yaxis
nlon=n_elements(xaxis)
nlat=n_elements(yaxis)
;minlon=min(xaxis)
;maxlon=max(xaxis)
;minlat=min(yaxis)
;maxlat=max(yaxis)
;resolt=abs(yaxis[1]-yaxis[0])

norbit=max(desc)
mask=fltarr(nlon,nlat)
tb=fltarr(nlon,nlat,nbo)
maskg[*]=!values.f_nan
tbg[*]=!values.f_nan
iheur=fltarr(nbo)
temp=fltarr(nlon,nlat)

norbit=0
for i=0,n_elements(tb1)-1 do begin
  while desc[i] eq norbit do begin
     ind=where(abs(lon[i]-xaxis) lt resol/2 and (abs(lat[i]-yaxis) lt resol/2,nbpt)
     if nbpt ne 0 then begin
        tbg[ind,norbit]=tb1[i]
        maskg[ind]=mask[i]
        temp[ind]=hour[i]
     endif 
  endwhile
  iheur[norbit]=mean(temp)
  norbit=norbit+1
endfor

  ;
  ; Creation du fichier NetCDF :
  ; ----------------------------
  htime=fix(iheur)
  mtime=fix((iheur-htime)*60)
  stime=fix((iheur-htime-mtime/60.)*3600)
  caldat, julday(1,1,yyyy)+iday-1,mttime,dtime,ytime
  file_ncdf=project_id_env+ 'AMSU/' $
        + string(yyyy,format='(I4.4)') + '/' $
        + string(mm,format='(I2.2)')   + '/' $
        + prefix+'ch5_' $
        + string(yyyy,format='(I4.4)') $
        + string(mm,format='(I2.2)') $
        + string(dd,format='(I2.2)') $
        +'_' $
        + string(htime,format='(I2.2)') $
        + string(mtime,format='(I2.2)') $
        + string(stime,format='(I2.2)') + '_' $
        + geomin + '_' $
        + geomax + '_' $
        + 'nadir.nc'
  print, 'iii : avant ', 'create_amsu_netcdf pour ' + file_ncdf
  create_amsu_netcdf, file_ncdf, ytime, mttime, dtime, htime, mtime, stime $
      ,xaxis,yaxis, tbg, maskg
  ; comment the next line to produce an image
  goto, ret0
  ;
  ; Visualisation :
  ; ---------------
  window
  loadct, 39
  map_set, limit=[minlat,minlon,maxlat,maxlon]

  tabcolor = MAP_IMAGE(bch5,Startx,Starty, COMPRESS=1, $
    LATMIN=minlat, LONMIN=minlon, $
    LATMAX=maxlat, LONMAX=maxlon, $
    min_value=0, missing=-999.)

  lewh=where(tabcolor ne -999., cnt, complement=lewhcmpl)
  if (cnt ne n_elements(tabcolor)) then begin
    tabcolor[lewhcmpl]=255
    tabcolor[lewh]=bytscl(tabcolor[lewh], top=254)
  endif else begin
    tabcolor=bytscl(tabcolor, top=254)
  endelse

  ; Display the warped image on the map at the proper position:
  TV, tabcolor, Startx, Starty

  ; Draw gridlines over the map and image:
  MAP_GRID, latdel=10, londel=10, /LABEL, /HORIZON  , color=0

  ; Draw continent outlines:
  MAP_CONTINENTS, /coasts, color=0

  ret0:
endwhile
if (debug eq 1) then begin
   print, 'fin grand while'
endif

close, lun
free_lun, lun

end
