function [comp]=composite(data,ind,jav,jap,dim_comp)

%COMPOSITE Calcul de composites

%+
%
% .. _composite.m:
%
% ===========
% composite.m
% ===========
%
% DESCRIPTION
% ===========
%
% Calcul de composites
%
% Entrees :
%
% data
%    donnees, vecteur ou matrice de n dimensions
% ind
%    indice des valeurs de data servant de bases au composite, vecteur
% jav
%    nombre de points avant chaque indice
% jap
%    nombre de points apres chaque indice
% dim_comp
%    dimension sur laquelle le composite est calcule
%
% Sortie :
%
% comp
%    composite
%
% EXAMPLES
% ========
%
% ::
%
%   >> x=[0:0.5:100];
%   >> f=sin(x); 
%   >> ind=find(f>0.96 & f<=1);
%   >> jav=3;
%   >> jap=8;
%   >> dim_comp=1;
%   >> % Calcul le composite en prenant 
%   >> % 3 points avant et 8 points apres chaque indice choisi
%   >> comp_f=composite(f,ind,jav,jap,dim_comp);
%   >> figure;plot(comp_f);
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id: composite.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
%-

usage='[comp]=composite(data,ind,jav,jap,dim_comp)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
dim=ndims(data);
%% Quand data a 2 dimensions
% teste si ces 2 dimensions ne cachent pas un vecteur (si oui, fait dim=1)
if dim==2
  if size(data,1)==1
    data=data';
    dim=1;
  end
  if size(data,2)==1
    dim=1;
  end
end

%% Teste si ind ne contient pas de valeurs inferieures ou egales a jav
% ou superieures a size(data,dim_comp)-jap
% sinon pb pour extraire les series voulues par la suite
if ~isempty(find(ind<jav))
  disp('Erreur dans ind par rapport a jav');
  return
end
if ~isempty(find(ind>size(data,dim_comp)-jap))
  disp('Erreur dans ind par rapport a jap');
  return
end

%% Adapte selon la taille de data
% pour pouvoir ensuite extraire les series voulues
x(1:2:dim*2)=',';
x(2:2:dim*2)=':';

if dim_comp==1
  dav='';
else
  dav(1:2:dim_comp*2-2)=':';
  dav(2:2:dim_comp*2-2)=',';
end

if dim_comp==dim
  dap='';
else
  dap(1:2:(dim-dim_comp)*2)=',';
  dap(2:2:(dim-dim_comp)*2)=':';
end

%% Extraction
size_ext=[length(ind) size(data)];
size_ext(dim_comp+1)=jav+1+jap;
% allocation
ext=zeros(size_ext); 
for n=1:length(ind)
  eval(['ext(n' x ')=data(' dav 'ind(n)-jav:ind(n)+jap' dap ');']);
end

%% Calcul du composite
comp=squeeze(nanmean(ext,1));



