#! /bin/sh
#+
#
# .. program:: create_gif.sh
#
# .. _create_gif.sh:
#
# =============
# create_gif.sh
# =============
#
# DESCRIPTION
# ===========
#
# $1  Nom fichier de sortie NetCDF (chemin complet)
# $2  Nom fichier de sortie GIF (chemin complet)
# $3  prefixe du prog  executer
# $4  Ajout d'une palette spciale 
#
# Appel des scripts FERRET pour la cration de sorties GIF associes
# aux fichiers NetCDF.
#
# .. only:: man
#
#    Figure is visible on PDF and HTML documents only.
#
# .. only:: html or latex
#
#     .. graphviz::
#
#        digraph create_gif {
#           graph [
#           rankdir="TB",
#           ]
#
#           msg_t5 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MSG/yyyy/mm/dd/yyyymmddhhmn_msg-prod_map_15min.nc"];
#           msg_t7 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MSG/yyyy/mm/dd/yyyymmddhhmn_msg-prod_map_15min.gif"];
#
#           log [shape=ellipse,fontname=Courier,label="${PROJECT_LOG}/create_gif.log{YYYYMMDDTHHMMSSZ}"];
#
#           create_gif [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/create_gif.sh",
#           label="${PROJECT}/src/create_gif.sh"];
#
#           {msg_t5} -> {create_gif} -> {log msg_t7}
#
#          }
#
# EXAMPLES
# ========
#
# You already used :ref:`get_msg.sh` to get MSG reference data of 20060801 and 
# you want to produce the GIF file::
#
#  $ create_gif.sh "/homedata/pinsard/varamma_d/MSG/2006/08/01/200608010000_msg-tb108_map_15min.nc" "/homedata/pinsard/varamma_d/MSG/2006/08/01/200608010000_msg-tb108_map_15min.gif" tb108
#
# And look at log file with ::
#
#  $ tlogd.sh create_gif
#
# and of course on files in ${PROJECT_ID}.
#
# SEE ALSO
# ========
#
# :ref:`guide data MSG <data_msg>`
#
# Called by :ref:`traite_msg-prod.sh`
#
# Use:
# :ref:`create_gif_msg-classif.jnl`
# :ref:`create_gif_msg-height.jnl`
# :ref:`create_gif_msg-pressure.jnl`
# :ref:`create_gif_msg-tb087.jnl`
# :ref:`create_gif_msg-tb097-dev.jnl`
# :ref:`create_gif_msg-tb108.jnl`
# :ref:`create_gif_msg-tb108z.jnl`
# :ref:`create_gif_msg-tb120.jnl`
# :ref:`create_gif_msg-tb134-dev.jnl`
# :ref:`create_gif_msg-temperature.jnl`
#
# Ferret_
#
# .. _Ferret: http://ferret.pmel.noaa.gov/Ferret/
#
# TODO
# ====
#
# .. todo::
#
# coding rules
#
# nicer parameters
#
# check parameters
#
# complete usage
#
# pal*.gif dans graphviz
#
# No pal*.gif found in original /home/climserv/eymard/
# only one found : /home/climserv/data.manage/Tarcyl/tarcyl2ncdf/pal_msg-classif.gif
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - pinsard 2011-06-01T09:18:41Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * correction on msg_t3 and msg_t4 terminology (in fact t5 and t7)
#
# - pinsard 2011-05-04T15:39:41Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * log file
#
# - pinsard 2011-05-02T08:25:53Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * complete header
#   * better exit status handling
#   * reduce stdout 
#   * no more intermidiate run*.jnl
# 
# - fplod 20100608T143812Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * minimal header
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
     echo "www : no specific posix checking"
     date_cmd=date
   ;;
   Darwin)
     set -o posix
     date_cmd=gdate
   ;;
   Linux)
     set -o posix
     date_cmd=date
   ;;
   *)
    set -o posix
   ;;
esac
unset system
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} ++"
#
hostname=$(hostname)
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
unset log_date
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "++" 1>> ${log}
echo "" 1>> ${log}
#
tool=ferret
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : tool ${tool} not found"
   exit 1
fi
unset status
unset tool
#
#
if [ -f ${2} ]
then
   echo "iii : ${2} already exist" >> ${log} 2>&1
   exit 0
fi
#
ferret -gif -nojnl -memsize 256 << EOF >> ${log} 2>&1
  CANCEL MODE VERIFY
  CANCEL DATA/ALL
  CANCEL SYMBOL/ALL
  GO create_gif_msg-${3}.jnl "${1}" "${2}" 
  quit
EOF
status=${?}
if [ ${status} -ne 0 ]
then
   echo "eee : pb with create_gif_${3}.jnl : ${status}" >> ${log} 2>&1
   exit 1 
fi
unset status
#
if [ "${4}" != "" -a "${4}" != "0" ]
then
  convert -draw "image Over ""${4}"" pal_msg-"${3}".gif" "${2}" "${2}" >> ${log} 2>&1
fi
#
exit
