; docformat = 'rst'
;+
;
;  .. function:: file_bathy_to_mem(lonmin, lonmax, latmin, latmax)
;
; .. _file_bathy_to_mem.pro:
;
; =====================
; file_bathy_to_mem.pro
; =====================
;
; DESCRIPTION
; ===========
;
; lit la carte de bathymetrie de S. Masson et remplit les tableaux du common ++
;
; .. only:: man or text
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph file_bathy_to_mem {
;
;           bathy [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MASK/ETOPO1_Ice_g_gmt4.nc"];
;           xxe [shape=tab,fontname=Courier,label="xxe array common"];
;           yye [shape=tab,fontname=Courier,label="yye array common"];
;           bate [shape=tab,fontname=Courier,label="bate array common"];
;
;           file_bathy_to_mem [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/file_bathy_to_mem.pro",
;           label="${PROJECT}/src/file_bathy_to_mem.pro"];
;
;           {bathy} -> {file_bathy_to_mem} -> {xxe yye bate}
;       }
;
; :param lonmin:
; :param lonmax:
; :param latmin:
; :param latmax:
;
; EXAMPLES
; ========
;
; ++::
;
;   lonmin=-25.
;   lonmax=25.
;   latmin=-5.
;   latmax=20.
;   result = file_bathy_to_mem(lonmin, lonmax, latmin, latmax)
;
; SEE ALSO
; ========
;
; :ref:`data_bathymetry`
;
; called by :ref:`traite_amsuab.sh`
;
; use ++
;
; next step :  ++
;
; TODO
; ====
;
; make it work : % Program caused arithmetic error: Floating illegal operand dans le read_netcf  la main
;
; improve log
;
; check args
;
; get rid of hard coded values -15, +15
;
; get rid of hard coded values XMINMESH=8000,XMAXMESH=15000, YMINMESH=4500,YMAXMESH=8500
; thoses ones oare valid  for West Africa ONLY
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20120416
;
;   * creation from extract_amsua.pro
;
;-
function file_bathy_to_mem $
                 , lonmin, lonmax, latmin, latmax
;
compile_opt idl2, strictarrsubs
;
@cm_project
@common
; Return to caller if errors
ON_ERROR, 2
;
result = -1
;
s = size(SCOPE_TRACEBACK(/STRUCTURE),/DIMENSION)
routine = (SCOPE_TRACEBACK(/STRUCTURE))[s-1].Routine
;
if key_performance EQ 1 THEN BEGIN
    time1 = SYSTIME(1)
ENDIF
;
; lecture fichier land - sea (S. Masson)
file=project_id_env+'/MASK/ETOPO1_Ice_g_gmt4.nc'
;attention: zone prise en compte limitee par le choix des nos en x et
;y dans initncdf. La region traitee ne doit pas exceder lonmin=-25 &
;lonmax=40 & latmin=-5 & latmax=40

initncdf,file, zaxisname='toto',xaxisname='lon',yaxisname='lat',XMINMESH=8000,XMAXMESH=15000, YMINMESH=4500,YMAXMESH=8500
domdef,lonmin-15., lonmax+15., latmin-15., latmax+15.
bathy=read_ncdf('z',file=file)
bate=bathy.arr gt 0
xxe1=reform(glamt[*,0])
zonx=where(xxe1 ge lonmin-15. and xxe1 le lonmax+15.)
xxe=xxe1[zonx]
yye1=reform(gphit[0,*])
zony=where(yye1 ge latmin-15. and yye1 le latmax+15.)
yye=yye1[zony]
;
IF key_performance EQ 1 THEN BEGIN
    msg = report(['ppp : ' + routine + ' : dure totale ' $
                   + string(SYSTIME(1)-time1,format='(F12.6)')])
ENDIF
;
result = 0
return, result
end
