function [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau] = intensityMSG_day(Temps, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau)

%INTENSITYMSG_DAY calcule les intensites de l'activite nuageuse estimees
%d'apres les donnees de temperature de brillance et un modele de nuages a
%deux couches (noyau + enveloppe externe), sur un jour.

%
%+
%
% ==================
% intensityMSG_day.m
% ==================
%
% .. function:: intensityMSG_day(Temps, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * Temps : Variable de temps des donnees de temperatures de brillances
%     (jour julien).
%   * TbMSG : Donnees brutes de temperatures de brillance.
%     dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
%   * Tps_SeuilInf (Facultatif) : Critere de temps minimum de vie d'un
%     nuage pour qu'il soit pris en compte (en nombre de quarts d'heure, 3
%     par defaut).
%   * Tb_SeuilSup (Facultatif) : Seuil de temperature de brillance
%     maximale delimitant un nuage convectif (en K, 235 par defaut).
%   * Tb_LimNoyau (Facultatif) : Seuil de temperature de brillance
%     delimitant le noyau dans notre modele a deux couches (en K, 190 par
%     defaut).
%
% - Donnees de sorties :
%
%   * ij_intensity : Donnees d'intensites estimees sur une journee.
%   * Tps_SeuilInf : Critere de temps minimum de vie d'un nuage pour qu'il
%     soit pris en compte.
%   * Tb_SeuilSup : Seuil de temperature de brillance maximale delimitant
%     un nuage convectif.
%   * Tb_LimNoyau : Seuil de temperature de brillance delimitant le noyau
%     dans notre modele a deux couches.
%
% Calcul des intensites de l'activite nuageuse estimees, sur une journee,
% d'apres les donnees de temperature de brillance et un modele de nuages a
% deux couches (noyau + enveloppe externe).
%
% Dans le cas de donnees manquantes, une interpolation 1D est realisee.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`varamma_startup.m`
%
% :func:`MSGbuildfullfilename`
% :func:`MSGread`
% :func:`extractedmatrixdata`
% :func:`simul_msg`
%
% :func:`intensityMSG_concat`
% :func:`int2precip`
%
% TODO
% ====
%
% use :func:`spatialresolution`
%
% check arg
%
% make it work when octave is running (cratos 3.4)
%
% demo 1 warning: division by zero
%
% demo2 et 3  interp1: table too short
%
% make it work when matlab running (cratos 7.4)
% demo 1 : Warning: Divide by zero.
%
% demo 2 There should be at least two data points.
%
% find matlab pc jason smooth equivalent in matlab locean and climserv and
% octave
% see http://www.aquaphoenix.com/lecture/matlab9/page3.html
%
% c'est quoi les 99 et 100 code en dur ! Il ne reste plus que le 100, c'est
% la nouvelle resolution de la matrice 100*100. Il faudrait trouver un
% moyen d'obtenir cette information et d'externaliser le changement de
% resolution car il ne sera pas toujours utile (en reflexion).
%
% Et si on veut observer plusieurs jours ou moins de un jour ?
% actuellement aa plante !!
%
% est-il raisonnable de modifier le tableau TbMGS en sortie ?
% IMHO : non
%
% fplod 20110621T083135Z cratos.locean-ipsl.upmc.fr (Linux)
% ne passe pas en matlab 2007 ni 2010 ::
%
%    The expression on this line will generate an error when executed.  The error will be: Error using ==> eps
%    Too many input arguments.
%
%    ??? Error using ==> interp2>linear at 303
%    The lengths of the X and Y vectors must match Z.
%
%    Error in ==> interp2 at 220
%        zi = linear(ExtrapVal,x,y,z,xi,yi);
%
%        Error in ==> intensityMSG_day at 280
%            m_TbMSG(timestep,:,:) = interp2(TbLiss(timestep,:,:),xi,yi);
%
% add plot at the end of demos
%
% Sur PC Jason :
% * pour le "switch application" erreur :
% ??? SWITCH expression must be a scalar or string constant.
% * Si "switch 'application'" pas d'erreur a ce niveau mais je me retrouve
% dans le cas "otherwise", ni matlab, ni octave.
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/intensityMSG_day.m $
%
% - fplod 20110805T094045Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix silly EPSAT vs MSG in demo
%   * correction of call in demos
%   * octave/image bwlabel ask for logical
%   * when used as a substitution on bwlabeln, bwlabel must be followed by a reshape
%
% - jaclod 2011-07-29
%
%   * Externalisation du passage en mm de precipitation suite a la
%     validation qui montre que cette formule n'est pas valable partout et
%     pour une zone plus etendue (utiliser la fonction int2precip).
%   * Modifications des demonstrations suite aux differentes
%     externalisations de fonctions (lecture, extraction, etc.).
%
% - jaclod 2011-07-27
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-22
%
%   * Application d'un facteur d'echelle et d'une constante pour passer des
%     intensites en unite arbitraire a des intensites en mm de
%     precipitation (y = 0.022685*x + 0.8366).
%
% - jaclod 2011-07-11
%
%   * Externalisation du changement de resolution (cf. fonction
%     spatialresolution).
%   * Plus de modification du tableau de donnees initiales en sortie.
%
% - fplod 20110704T104826Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * bwlabel from local (fplod) image package when octave running
%   * use try/catch around interp2
%   * dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
%
% - fplod 20110621T083244Z cratos.locean-ipsl.upmc.fr (Linux)
%
%   * diff of eps syntxe beteen matlab and octave
%
% - fplod 20110620T133342Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add demo with time hole (demo 2 is with no time hole)
%   * new detection of time hole
%     see http://blinkdagger.com/matlab/matlab-tips-and-tricks-on-manipulating-1-d-arrays-vectors/
%
%     ** Si la matrice de donnees, TbMSG, n'a pas une dimension temporelle de 96, alors il manque des donnees et il faut interpoler.**
%
%    This acception is wrong : now we detect time holes greater than 1/96 day (15mn) to know if interpolation is needed.
%
% - fplod 20110609T093726Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * TbMSG is now a (time, lon,lat) array (but not finish ...)
%
% - pinsard 2011-06-08T15:01:07Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * Temps is now julian day
%
% - fplod 20110307T142316Z cratos.locean-ipsl.upmc.fr (Linux)
%
%   * add demo with simulated data (not ok running octave)
%   * complete TODO
%
% - fplod 20110304T085752Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 2011-03-02
%
%   * Ajout de la documentation et de la demonstration.
%
% - jaclod 2011-02-25
%
%   * Creation.
%
%-


% Appel de la variable global 'application' (Il faut s'assurer d'avoir
% execute le programme 'varamma_startup' dans un premier temps).
global application;

usage='[ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau] = intensityMSG_day(Temps, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%%%%%%%%%%%%%
% Parametres
%%%%%%%%%%%%%

% Si les parametres correspondant aux seuils n'ont pas ete donnes par
% l'utilisateur, des valeurs par defaut sont prises.
if exist('Tb_SeuilSup','var')~=1;
    % Seuil de Tb en Kelvin (Temperature de brillance).
    Tb_SeuilSup = 235;
end

if exist('Tb_LimNoyau','var')~=1;
    % Limite Noyau-Ext de Tb en Kelvin.
    Tb_LimNoyau = 190;
end

if exist('Tps_SeuilInf','var')~=1;
    % Seuil de temps en quarts d'heure.
    Tps_SeuilInf = 3;
end

% TBMSG dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
idim_time=1;
idim_lon=2;
idim_lat=3;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Interpolation pour les donnees manquantes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% On cherche quels sont les pas de temps ou les mesures sont presentes. La
% matrice "mesures_15min" contient alors les numeros des quarts d'heure que
% l'on a.
mTemps = Temps/24 + datenum(1960,01,01);
mTemps = datevec(mTemps);
mesures_15min = (mTemps(:,4)*4 + mTemps(:,5)/15)'+1;

% Avant de regarder s'il y a des donnees manquantes, on va supprimer les
% donnees absurdes donnees deliberement et indiquer dans le descriptif du
% fichier. On a alors des 656 comme valeurs (exemple pour le 31 juillet
% 2006, au quart d'heure 28).
mesures_absurdes = find(TbMSG(:,1,1) == 656);

% On fait une boucle pour supprimer ces valeurs (si on avait rien trouve,
% 'mesures_absurdes' est une matrice vide et la boucle ne se fait pas).
for i = 1 : size(mesures_absurdes,1);

    % On commence par supprimer le dernier pas de temps absurde pour eviter
    % le decalage des pas de temps lorsqu'on supprime les premiers
    % d'abords.
    suppr = mesures_absurdes(size(mesures_absurdes,1)-(i-1));
    mesures_15min(suppr) = [];
    TbMSG(suppr,:,:) = [];

end

% Si la matrice de donnees, TbMSG, n'a pas une dimension temporelle de 96,
% alors il manque des donnees et il faut interpoler.
if size(TbMSG,idim_time)~=96;

    % On interpole apres avoir converti, par securite, notre matrice en
    % type 'double'.
    TbMSG = double(TbMSG);
    TbMSG = interp1(mesures_15min,TbMSG,1:96);

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lissage et interpolation
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Creation d'une matrice de la taille de 'TbMSG' qui contiendra les donnees
% lissees.
TbLiss = zeros(size(TbMSG));

for timestep = 1 : size(TbMSG,idim_time);

    % Lissage selon la methode "lowess".
    if ispc()
       TbLiss_15min = smooth(TbMSG(timestep,:,:),'lowess');
    else

       TbLiss_15min = TbMSG(timestep,:,:);

       % Message d'avertissement vis-a-vis du non lissage sur la machine de
       % l'utilisateur.
       if timestep == 1;
           disp('www : no smooth available using on non-pc plateform');
       end

    end

    % Recuperation des donnees de chaque pas de temps dans la matrice
    % generale.
    TbLiss_15min = reshape(TbLiss_15min,size(TbMSG,idim_lon),size(TbMSG,idim_lat));
    TbLiss(timestep,:,:) = TbLiss_15min;

end

m_TbMSG = TbLiss;

%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Labellisation des nuages
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% La labellisation different selon le programme utilise.

switch application

   case {'matlab'}
      DetectionNuage = bwlabeln(m_TbMSG <= Tb_SeuilSup);

   case {'octave'}
      disp(['www : no bwlabeln available using ', application]);
      disp('www : bwlabel used instead');
      m_TbMSG_logical=logical(m_TbMSG);
      DetectionNuage_2D = bwlabel(m_TbMSG_logical <= Tb_SeuilSup,8);
      DetectionNuage=reshape(DetectionNuage_2D,size(m_TbMSG_logical,1),size(m_TbMSG_logical,2),size(m_TbMSG_logical,3));
      clear DetectionNuage_2D
   otherwise
      error('unknown application running');

end

numax = max(DetectionNuage(:));

% Boucle sur les nuages, pour eliminer ceux trop brefs.
for num_nuage = 1 : numax;

    disp(['Analyse du nuage ' num2str(num_nuage) ' sur ' num2str(numax)])
    % On cherche a quel quart d'heure le nuage apparait pour la premiere
    % fois.
    timestep = 1;
    while size(find(DetectionNuage(timestep,:,:) == num_nuage), 1) == 0 && timestep ~= size(TbMSG,idim_time)-(Tps_SeuilInf-1);
        timestep = timestep + 1;
    end

    % On verifie que le nuage est present, depuis le temps ou il
    % apparait jusqu'a atteindre le seuil definit precedemment.
    Elimination = 0;
    timestepSup = 0;

    while timestepSup ~= Tps_SeuilInf-1 && Elimination == 0;
        % Si parmi les quarts d'heure oa le nuage doit atre present, il
        % n'est pas detecte, alors il ne satisfait pas le critere de
        % temps et n'est plus pris en compte.
        if size(find(DetectionNuage(timestep+timestepSup,:,:) == num_nuage), 1) == 0;
            Elimination = 1;
            DetectionNuage(DetectionNuage == num_nuage) = 0;
        end

        timestepSup = timestepSup + 1;

    end

end

% On labellise une nouvelle fois.
switch application

   case {'matlab'}
       DetectionNuage = bwlabeln(DetectionNuage);

   case {'octave'}
       disp(['www : no bwlabeln available using ', application]);
       disp('www : bwlabel used instead');
       DetectionNuage_logical = logical(DetectionNuage);
       DetectionNuage_2D = bwlabel(DetectionNuage_logical,8);
       DetectionNuage=reshape(DetectionNuage_2D,size(DetectionNuage_logical,1),size(DetectionNuage_logical,2),size(DetectionNuage_logical,3));
       clear DetectionNuage_2D

   otherwise
       error('unknown application running');

end

numax = max(DetectionNuage(:));

%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modele de nuages a deux couches
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Creation d'une matrice qui contiendra les valeurs des Tb dans ce modele.
Tb2couches = zeros(size(m_TbMSG));

% Boucle sur les nuages.
for num_nuage = 1 : numax;

    % On garde la Tb moyenne du noyau dans sa zone.
    ZoneNoyau = find(m_TbMSG <= Tb_LimNoyau & DetectionNuage == num_nuage);
    Tb2couches(ZoneNoyau) = mean(m_TbMSG(ZoneNoyau));

    % De meme pour la zone exterieure.
    ZoneExt = find(m_TbMSG > Tb_LimNoyau & m_TbMSG <= Tb_SeuilSup & DetectionNuage == num_nuage);
    Tb2couches(ZoneExt) = mean(m_TbMSG(ZoneExt));

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%
% Intensites
%%%%%%%%%%%%%

Tb2couches(Tb2couches==0)=NaN;

% On definit l'intensite pour chaque point comme la somme de la difference
% entre la temperature de brillance de reference (Tb_SeuilSup, valeur seuil
% du nuage) et la temperature de brillance du nuage a chaque pas de temps.
Intensity = Tb_SeuilSup - Tb2couches;
ij_intensity = squeeze(nansum(Intensity,idim_time));

%%%%%%%%%%%%

end

%!demo
%! % From scratch with simulated data during 1 day::
%! clear all
%! varamma_startup;
%! more off
%! index_simulation = uint8(3);
%! [lon_value, lat_value, datejul_value, datestr_value, TbMSG] = simul_msg(index_simulation);
%! whos
%! Tb_SeuilSup = 235;
%! Tps_SeuilInf = 3;
%! Tb_LimNoyau = 210;
%! [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau] = intensityMSG_day(datejul_value, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau);

%!demo
%! % From real  file :file:`${PROJECT_ID}/MSG/2006/08/msg-tb108_2006-08-01_15min.nc` (no time hole in this file) ::
%! clear all
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! latmin = 10;
%! latmax = 20;
%! lonmin = -20;
%! lonmax = -10;
%! [fullfilename] = MSGbuildfullfilename('normal', Annee, Mois, Jour);
%! [TbMSG, Temps, Longitudes, Latitudes] = MSGread('normal', fullfilename);
%! [TbMSG, Temps, Longitudes, Latitudes] = extractedmatrixdata(TbMSG, Temps, Longitudes, Latitudes, Temps(1), Temps(size(Temps,2)), lonmin, lonmax, latmin, latmax);
%! Tb_SeuilSup = 235;
%! Tps_SeuilInf = 3;
%! Tb_LimNoyau = 210;
%! [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau] = intensityMSG_day(Temps, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau);

%!demo
%! % From real  file :file:`${PROJECT_ID}/MSG/2006/07/msg-tb108_2006-07-31_15min.nc` (time hole in this file) ::
%! clear all
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '07';
%! Jour = '31';
%! latmin = 10;
%! latmax = 20;
%! lonmin = -20;
%! lonmax = -10;
%! [fullfilename] = MSGbuildfullfilename('normal', Annee, Mois, Jour);
%! [TbMSG, Temps, Longitudes, Latitudes] = MSGread('normal', fullfilename);
%! [TbMSG, Temps, Longitudes, Latitudes] = extractedmatrixdata(TbMSG, Temps, Longitudes, Latitudes, Temps(1), Temps(size(Temps,2)), lonmin, lonmax, latmin, latmax);
%! Tb_SeuilSup = 235;
%! Tps_SeuilInf = 3;
%! Tb_LimNoyau = 210;
%! [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau] = intensityMSG_day(Temps, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau);
