function [result]=sigmoide3(t, a1c, a2c, mc, nc, a1d, a2d, md, nd, t1c, t2c, t1d, t2d)

%+
%
%
% ===========
% sigmoide3.m
% ===========
%
% .. function:: sigmoide3(t, a1c, a2c, mc, nc, a1d, a2d, md, nd, t1c, t2c, t1d, t2d)
%
% DESCRITPITON
% ============
%
%   :param t: time in number of days
%   :type t: uint16
%   :raise t: required
%
%   :param a1c: fitting increasing part of sigmoide
%   :type a1c: double
%   :raise a1c: required
%
%   :param a2c: fitting increasing part of sigmoide
%   :type a2c: double
%   :raise a2c: required
%
%   :param a1d: fitting decreasing part of sigmoide
%   :type a1d: double
%   :raise a1d: required
%
%   :param a2d: fitting decreasing part of sigmoide
%   :type a2d: double
%   :raise a2d: required
%
%   :param mc: fitting parameter
%   :type mc: double
%   :raise mc: required
%
%   :param nc: fitting parameter
%   :type nc: double
%   :raise nc: required
%
%   :param md: fitting parameter
%   :type md: double
%   :raise md: required
%
%   :param t1c: number of columns for increasing sigmoide
%   :type t1c: uint16
%   :raise t1c: required
%
%   :param t2c:  number of columns for increasing sigmoide
%   :type t2c: uint16
%   :raise t2c: required
%
%   :param t1d: number of columns for decreasing sigmoide
%   :type t1d: uint16
%   :raise t1d: required
%
%   :param t2d: number of columns for decreasing sigmoide
%   :type t2d: uint16
%   :raise t2d: required
%
%   ++
%
%   - definition des indices correspondant  l'amplitude total et la
%     faible valeur du LAI
%
%   - description deux branches de la fonction sigmode, se basant
%     sur l'evolution du LAI pour boucler sur les numeros de dates
%
% TODO
% =====
%
% trouver les quivalents en numero de jour dans l'anne de t1c, t2c, t1d, et t2d
% pour la demo
%
% faire le menage de touts les programmes sigmoide qui trainent
%
% verif parametres
%
% comprendre pourqoui le resulat de la fonction depend du type de t, t1c, et
% t2c (unit16 ou double)
%
% valeur d'ajustement de l'ampliude (/5) en dur ici. est-ce que l'on doit la garder, la mettre en parametre ...
%
%
% automatisation des parametres d'ajustement (pas ici !)
%
% EVOLUTION
% =========
%
% $Id$
%
% $URL$
%
% - soclod/fplod
%
%   * limitation des dessins des branches dans l'intervalle t1c,t2c et t1d,t2d
%
% - soclod 20110824
%
%   * creation
%
%-
%
arg_info=whos('t');
if ~strcmp(arg_info.class,'uint16')
   disp(['Incorrect type of arg t ' arg_info.class]);
   whos t
   error(usage);
end
clear arg_info
%
arg_info=whos('a1c');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg a1c ' arg_info.class]);
   whos a1c
   error(usage);
end
clear arg_info
%
arg_info=whos('a2c');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg a2c ' arg_info.class]);
   whos a2c
   error(usage);
end
clear arg_info
%
arg_info=whos('a1d');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg a1d ' arg_info.class]);
   whos a1d
   error(usage);
end
clear arg_info
%
arg_info=whos('a2d');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg a2d ' arg_info.class]);
   whos a2d
   error(usage);
end
clear arg_info
%
arg_info=whos('t1c');
if ~strcmp(arg_info.class,'uint16')
   disp(['Incorrect type of arg t1c ' arg_info.class]);
   whos t1c
   error(usage);
end
clear arg_info
%
arg_info=whos('t2c');
if ~strcmp(arg_info.class,'uint16')
   disp(['Incorrect type of arg t2c ' arg_info.class]);
   whos t2c
   error(usage);
end
clear arg_info
%
arg_info=whos('t1d');
if ~strcmp(arg_info.class,'uint16')
   disp(['Incorrect type of arg t1d ' arg_info.class]);
   whos t1d
   error(usage);
end
clear arg_info
%
arg_info=whos('t2d');
if ~strcmp(arg_info.class,'uint16')
   disp(['Incorrect type of arg t2d ' arg_info.class]);
   whos t2d
   error(usage);
end
clear arg_info

result=[];
usage='[result]=sigmoide3(t, a1c, a2c, mc, nc, a1d, a2d, md, nd, t1c, t2c, t1d, t2d)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end

nbdate=size(t,2);

% initialisation des varaiables
ac=zeros(1,nbdate);
ad=zeros(1,nbdate);
%
t=double(t);
t1c=double(t1c);
t2c=double(t2c);
% description de la branche de la croissance de la fonction
for index_tc=t1c:t2c
    ac(index_tc)=(a1c+a2c*(1/(1+exp(mc-nc*t(index_tc)))))/5;
end
%
% description de la branche de la decroissance de la fonction
% sigmode
for index_td=t1d:t2d
    ad(index_td)=(a1d+a2d*(1/(1+exp(-(md-nd*t(index_td))))))/5;
end
%
% dessine la branche croissante
plot(t(t1c:t2c),ac(t1c:t2c),'rx');
hold on
%
% dessine la branche decroissante
plot(t(t1d:t2d),ad(t1d:t2d),'b*');
%
xlim([min(t) max(t)])
xlabel('t');
ylabel('y');
title('fonction sigmode');

result=0;

end

%!demo
%! % To plot function sigmoide
%! % t = numero de jours
%! % y fonction de t et des 4x2 parametres du sigmoide
%! clear all
%! close all
%! varamma_startup
%! more off
%! t = uint16(1:8:361);
%! % parametres d'ajustement correspondant  la croissance
%! mc = 30.11;
%! nc = 0.13;
%! % les valeurs du LAI correspondant a l'amplitude totale et  la
%! % faible valeur
%! a1c = 1.34;
%! a2c = 4.10;
%! % parametres d'ajustement de la branche correspondant  la decroissance
%! md = 37.97;
%! nd = 0.13;
%! %les valeurs du LAI correspondant a l'amplitude totale et  la
%! % faible valeur
%! a1d = 1.18;
%! a2d = 4.25;
%! % en considrant un date de dbut de la croissance la 20me semaine cad jour 153
%! % et avec une date de maturit fixe  la semaine 35 jour 273
%! t1c = uint16(20);
%! t2c = uint16(35);
%! t1d = uint16(30);
%! t2d = uint16(46);
%! [result] = sigmoide3(t, a1c, a2c, mc, nc, a1d, a2d, md, nd, t1c, t2c, t1d, t2d)
