function [datestr_value, precip_value]=simul_precip(station,index_simulation)

%SIMUL_PRECIP fill array precipitation 2D array and associated arrays datestr
%with simulated data

%
%+
%
% ==============
% simul_precip.m
% ==============
%
% .. function:: simul_precip(station,index_simulation)
%
% DESCRIPTION
% ===========
%
%    :param index_simulation: 1
%    :type index_simulation: uint8
%    :raise index_simulation: required
%
%    :param station: station
%    :type station: string
%    :raise station: required
%
%
% Charge en mmoire un tableau 2D simul **precip_value** de prcipitation dans :
%
% Simulation #1
%   donnes pendant la mousson de 2006
%
% Les dates au format `yyyymmdd` sont stocks dans le tableau **datestr_value**.
%
% EXAMPLES
% ========
%
% From scratch to create short array of precipitation and associated array datestr:
%
% see demo 1
%
% To write these arrays in
% file:`${VARAMMA_OD}/PRECIP/barkedji_pluie_2006_write_precip.csv`::
%
%   octave> result=write_precip(datestr_value, precip_value);
%
% From scratch to create long array of precipitation and associated array datestr:
%
% see demo 2
%
% To write these arrays in
% file:`${VARAMMA_OD}/PRECIP/barkedji_pluie_2006_write_precip.csv`::
%
%   octave> result=write_precip(datestr_value, precip_value);
%
% SEE ALSO
% ========
%
% :ref:`guide data precipitation <data_precipitation_insitu>`
%
% :func:`write_precip`
%
% TODO
% ====
%
% des valeurs de precipitation plus ralistes y compris des NaN
%
% returned values when error
%
% pb with demo 2
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/simul_precip.m $
%
% - fplod 20110816T073113Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace int8 by uint8 for integer parameters
%
% - fplod 20110228T115056Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * examples moved in demo
%   * use int2str instead of num2str
%
% - fplod 20110221T155750Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * remove simulated geolocation
%
% - fplod 20110112T110544Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
%
result=-1;
%
usage='[datestr_value, precip_value]=simul_precip(station,index_simulation)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('index_simulation');
if ~strcmp(arg_info.class,'uint8')
   disp(['Incorrect type of arg index_simulation ' arg_info.class]);
   whos index_simulation
   error(usage);
end
clear arg_info
%
%
arg_info=whos('station');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg station ' arg_info.class]);
   whos station
   error(usage);
end
clear arg_info
%
% dfinition de la zone gographique
% dfinition de la zone temporelle
if (index_simulation == 1)
   yyyy=uint16(2006);
   datenum_value=datenum(yyyy,6,1):1:datenum(yyyy,11,eomday(yyyy,11));
   datestr_value=datestr(datenum_value,'yyyymmdd');
   clear yyyy
   clear datenum_value
else
   error(['eee : unknow simulation ' int2str(index_simulation)]);
end
%
nb_geolocation=1;
%
nb_datestr=size(datestr_value,1);
%
% cration de tableau precipitation
precip_value=zeros(nb_geolocation,nb_datestr,'double');
for index_geolocation=1:nb_geolocation
    for index_datestr=1:nb_datestr
        precip_value(index_geolocation,index_datestr)=index_datestr/10.;
    end
end
clear nb_geolocation
clear index_geolocation
clear nb_datestr
clear index_datestr
%
whos;
%
result=0;
%
end

%!demo
%! % From scratch to create short array of precipitation and associated array datestr::
%! varamma_startup
%! more off
%! index_simulation = uint8(1);
%! station = 'barkedji';
%! [datestr_value, precip_value] = simul_precip(station,index_simulation)

%!demo
%! % From scratch to create long array of precipitation and associated array datestr::
%
%! varamma_startup
%! more off
%! echo on
%! index_simulation = uint8(2);
%! station = 'barkedji';
%! [datestr_value, precip_value] = simul_precip(station,index_simulation)
