#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

__docformat__ = 'reStructuredText'
__autodoc__ = ['simul_zi']

import sys

def simul_zi(index_simulation):
    """

    ========
    simul_zi
    ========

    .. :py:function:: simul_zi(index_simulation)

    DESCRIPTION
    ===========

    Charge en mmoire des info simules de zones of interest (zi)

    Simulation #1
      3 zones of interest named ``zone``\ xx

    Parameters
    ----------

    index_simulation : {1}

    Returns
    -------

    west_value : array_like
       west most longitudes

    east_value : array_like
       east most longitudes

    north_value : array_like
       north most latitudes

    south_value : array_like
       south most latitudes

    zi_code : array_like of strings
       codes of the zone of interest

    zi_description: array_like of strings
       descriptions of the zone of interest

    Raises
    ------

    Missing parameters


    EXAMPLES
    ========

    >>> # From scratch to create 3 zones of interest associated arrays::
    >>>
    >>> index_simulation = 1 
    >>> (west_value, east_value, north_value, south_value, zi_code, zi_description) = simul_zi(index_simulation)
    >>> print(west_value, east_value, north_value, south_value, zi_code, zi_description)
    ([-19.0, -18.0, -17.0], [-14.0, -13.0, -12.0], [11.0, 12.0, 13.0], [9.0, 10.0, 11.0], ['zone01', 'zone02', 'zone03'], ['zone 01', 'zone 02', 'zone 03'])

    To write these arrays in
    :file:`${PROJECT_OD}/maps/varamma_zi_write_zi_py.csv`::

    see :func:`write_zi`

    To plot the zones of interest on a map grid:

    see :func:`plot_zi`

    SEE ALSO
    ========

    :ref:`zones`

    :py:func:`write_zi`
    :py:func:`plot_zi`

    TODO
    ====

    get rid of matlab stuff

    include in sphinx processing

    EVOLUTIONS
    ==========

    $Id: simul_zi.py 348 2011-08-17 07:12:51Z pinsard $

    $URL$

    - fplod 20110907T151038Z aedon.locean-ipsl.upmc.fr (Darwin)

      * complete description
      * no more preallocation

    - fplod 20110816T103232Z aedon.locean-ipsl.upmc.fr (Darwin)

      * creation from simul_zi.m

    """

    result = -1
    #
    usage = '(west_value, east_value, north_value, south_value, zi_code, zi_description) = simul_zi(index_simulaion)'
    # ++ matlab if nargin~=1
    # ++ matlab    disp(['Incorrect number of arguments ' num2str(nargin) ])
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # ++ matlab arg_info=whos('index_simulation')
    # ++ matlab if ~strcmp(arg_info.class,'uint8')
    # ++ matlab    disp(['Incorrect type of arg index_simulation ' arg_info.class])
    # ++ matlab    whos index_simulation
    # ++ matlab    error(usage)
    # ++ matlab end
    # ++ matlab #
    # ++ matlab #
    # ++ matlab # dfinition de la zone gographique

    if index_simulation == 1:
        nb_zi = 3
    else:
        print ('eee : unknown simulation %i' % (index_simulation))
        sys.exit(1)

    west_value = []
    east_value = []
    north_value = []
    south_value = []
    zi_description = []
    zi_code = []

    if index_simulation == 1:
        for index_zi in range(0, nb_zi):
            west_value.append(-20. + index_zi+1)
            east_value.append(-15. + index_zi+1)
            north_value.append(10.+ index_zi+1)
            south_value.append(8.+ index_zi+1)
            #
            zi_description.append('zone ' + str(index_zi+1).zfill(2))
            zi_code.append('zone' + str(index_zi+1).zfill(2))
    else:
        print ('eee : unknown simulation %i' % (index_simulation))
        sys.exit(1)
    #
    #whos
    #
    result = 0
    #
    return west_value, east_value, north_value, south_value, zi_code, zi_description

# Run main, if called from the command line
if __name__ == '__main__':
    import doctest
    doctest.testmod()
